@@ -88,7 +88,7 @@ class Oracle:
     def makePredictions(self,chr):
         passed, failed = [], []
         for reso,sublist in self.__resolution_sub_lists.items():
-          print ('ORACLE is running at', reso, 'kb', 'on chr', chr)
+          print ('ORACLE is running at', reso, 'kb', 'on', chr)
 
           if len(failed)>0:
             # failed.drop(['prediction'],axis=1,inplace=True)
@@ -107,11 +107,16 @@ class Oracle:
             batch[index,:self.__width-1,:self.__width-1,0] = self.preprocess(mat)
           prediction = self.__model.predict(batch)
           sublist['score_oracle_'+str(reso)] = prediction.reshape(prediction.shape[0],)
-          passed.append(sublist[sublist['score_oracle_'+str(reso)] >= 0.5])
+          psd = sublist[sublist['score_oracle_'+str(reso)] >= 0.5]
+          passed.append(psd)
           failed = sublist[sublist['score_oracle_'+str(reso)] < 0.5]
+          print (psd.shape[0],'calls passed ORACLE.')
+          print (failed.shape[0], 'calls failed ORACLE.')
+          # psd.to_csv(filename + '_ORACLE_passed_'+str(reso)+'.bedpe', sep="\t", index=False)
+          # failing.to_csv(filename + '_ORACLE_failed_'+str(reso)+'.bedpe', sep="\t", index=False)
 
 
-        return (pd.concat(passed,ignore_index = True), failed)
+        return (pd.concat(passed,ignore_index = True).fillna('.'), failed)
 
 
     def run(self):
@@ -121,7 +126,7 @@ class Oracle:
           passed.append(preds[0])
           failed.append(preds[1])
 
-        return (pd.concat(passed,ignore_index = True), pd.concat(failed,ignore_index=True))
+        return (pd.concat(passed,ignore_index = True).fillna('.'), pd.concat(failed,ignore_index=True))
 
 
 # python3 oracle.py <file.hic> </dir/models> </dir/bedpe> <norm>
